@@ -1,9 +1,7 @@
-
 import copy
 
-from nctoolkit.cleanup import cleanup, disk_clean
+from nctoolkit.cleanup import cleanup
 from nctoolkit.runthis import run_cdo, tidy_command
-from nctoolkit.session import nc_safe, session_info
 from nctoolkit.show import nc_years
 from nctoolkit.temp_file import temp_file
 
