@@ -1,4 +1,3 @@
-
 import atexit
 import copy
 import multiprocessing as mp
@@ -10,25 +9,25 @@ import string
 import subprocess
 import warnings
 import urllib.request
+import platform
 
 from netCDF4 import Dataset
 
-from nctoolkit.cleanup import cleanup, clean_all,deep_clean, temp_check
-from nctoolkit.create_ensemble import create_ensemble
+from nctoolkit.cleanup import cleanup, clean_all, temp_check
 from nctoolkit.flatten import str_flatten
-from nctoolkit.generate_grid import generate_grid
 from nctoolkit.runthis import run_cdo
-from nctoolkit.session import nc_safe, nc_protected, session_info
+from nctoolkit.session import nc_protected, session_info, nc_safe
 from nctoolkit.show import nc_variables, nc_years, nc_months, nc_levels, nc_times
 from nctoolkit.temp_file import temp_file
 
+
 # A custom format for warnings.
 def custom_formatwarning(msg, *args, **kwargs):
     # ignore everything except the message
     return str(msg) + "\n"
 
-warnings.formatwarning = custom_formatwarning
 
+warnings.formatwarning = custom_formatwarning
 
 # set up the session info
 letters = string.ascii_lowercase
@@ -39,8 +38,14 @@ session_info["temp_dir"] = "/tmp/"
 session_info["thread_safe"] = False
 session_info["lazy"] = False
 session_info["precision"] = None
-result = os.statvfs("/tmp/")
-session_info["size"] = result.f_frsize * result.f_bavail
+
+if platform.system() == "Linux":
+    result = os.statvfs("/tmp/")
+    session_info["size"] = result.f_frsize * result.f_bavail
+else:
+    session_info["size"] = 0
+
+
 session_info["latest_size"] = 0
 session_info["cores"] = 1
 
@@ -50,18 +55,19 @@ atexit.register(clean_all)
 # run temp_check to see if any files are held over from previous sessions
 temp_check()
 
+
 def is_url(x):
     regex = re.compile(
-            r'^(?:http|ftp)s?://' # http:// or https://
-            r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|' #domain...
-            r'localhost|' #localhost...
-            r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})' # ...or ip
-            r'(?::\d+)?' # optional port
-            r'(?:/?|[/?]\S+)$', re.IGNORECASE)
-
-    return re.match(regex,x) is not None
-
+        r"^(?:http|ftp)s?://"  # http:// or https://
+        r"(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|"  # domain...
+        r"localhost|"  # localhost...
+        r"\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})"  # ...or ip
+        r"(?::\d+)?"  # optional port
+        r"(?:/?|[/?]\S+)$",
+        re.IGNORECASE,
+    )
 
+    return re.match(regex, x) is not None
 
 
 def options(**kwargs):
@@ -109,7 +115,7 @@ def options(**kwargs):
 
 def convert_bytes(num):
     """
-     A function to make file size human readable
+    A function to make file size human readable
     """
     for x in ["bytes", "KB", "MB", "GB", "TB"]:
         if num < 1000.0:
@@ -126,7 +132,7 @@ def file_size(file_path):
         return file_info.st_size
 
 
-def open_data(x=None, suppress_messages=False, checks=False):
+def open_data(x=None, suppress_messages=False, checks=False, **kwargs):
     """
     Read netcdf data as a DataSet object
 
@@ -134,10 +140,18 @@ def open_data(x=None, suppress_messages=False, checks=False):
     ---------------
     x : str or list
         A string or list of netcdf files or a single url. The function will check the files exist. If x is not a list, but an iterable it will be converted to a list. If a url is given the file will be downloaded before processing.
+    thredds : boolean
+        Are you accessing a thredds server? Must end with .nc.
     checks: boolean
         Do you want basic checks to ensure cdo can read files?
     """
 
+    thredds = False
+
+    for key in kwargs:
+        if key == "thredds":
+            thredds = kwargs[key]
+
     # make sure data has been supplied
     if x is None:
         raise ValueError("No data was supplied!")
@@ -149,15 +163,32 @@ def open_data(x=None, suppress_messages=False, checks=False):
             if type(ff) is not str:
                 raise TypeError("You have not supplied an iterable made of file paths!")
 
+    if type(x) is list:
+        if len(x) == 1:
+            x = x[0]
+
     # check the files provided exist
+
     if type(x) is str:
-        if os.path.exists(x) == False:
+        if os.path.exists(x) is False:
 
             if is_url(x):
-                new_x = temp_file(".nc")
-                print(f"Downloading {x}")
-                urllib.request.urlretrieve(x, new_x)
-                x = new_x
+
+                if thredds is False:
+                    new_x = temp_file(".nc")
+                    print(f"Downloading {x}")
+                    urllib.request.urlretrieve(x, new_x)
+                    x = new_x
+                else:
+                    out = subprocess.run(
+                        "cdo sinfo " + x,
+                        shell=True,
+                        stdout=subprocess.PIPE,
+                        stderr=subprocess.PIPE,
+                    )
+                    if "Open failed" in str(out.stderr):
+                        raise ValueError(f"{x} is not compatible with CDO!")
+
             else:
                 raise ValueError("Data set " + x + " does not exist!")
 
@@ -192,43 +223,87 @@ def open_data(x=None, suppress_messages=False, checks=False):
         if len(x) < orig_size:
             warnings.warn(message="Duplicates in data set have been removed!")
 
+    # if type(x) is list:
+    #    if len(x) == 1:
+    #        x = x[0]
+
     if type(x) is list:
-        if checks:
-            if suppress_messages == False:
-                warnings.warn("Performing basic checks on ensemble files")
-        if len(x) == 0:
-            raise ValueError("You have not provided any files!")
+        if thredds is False:
+            if checks:
+                if suppress_messages is False:
+                    warnings.warn("Performing basic checks on ensemble files")
+            if len(x) == 0:
+                raise ValueError("You have not provided any files!")
 
-        for ff in x:
+            for ff in x:
 
-            if os.path.exists(ff) == False:
-                raise ValueError("Data set " + ff + " does not exist!")
-            else:
-                if checks:
-                    out = subprocess.run(
-                        "cdo sinfo " + ff,
-                        shell=True,
-                        stdout=subprocess.PIPE,
-                        stderr=subprocess.PIPE,
-                    )
-                    if "Open failed" in out.stderr.decode("utf-8"):
-                        mes = (
-                            out.stderr.decode("utf-8")
-                            .replace("cdo    sinfo: ", "")
-                            .replace("<\n", "")
-                            .replace("\n", "")
+                if os.path.exists(ff) is False:
+                    raise ValueError("Data set " + ff + " does not exist!")
+                else:
+                    if checks:
+                        out = subprocess.run(
+                            "cdo sinfo " + ff,
+                            shell=True,
+                            stdout=subprocess.PIPE,
+                            stderr=subprocess.PIPE,
                         )
-                        mes = re.sub(" +", " ", mes)
-                        raise ValueError(mes)
-                nc_safe.append(ff)
-                nc_protected.append(x)
+                        if "Open failed" in out.stderr.decode("utf-8"):
+                            mes = (
+                                out.stderr.decode("utf-8")
+                                .replace("cdo    sinfo: ", "")
+                                .replace("<\n", "")
+                                .replace("\n", "")
+                            )
+                            mes = re.sub(" +", " ", mes)
+                            raise ValueError(mes)
+                    nc_safe.append(ff)
+                    nc_protected.append(x)
+        else:
+            out = subprocess.run(
+                "cdo sinfo " + x[0],
+                shell=True,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+            )
+            if "Open failed" in str(out.stderr):
+                raise ValueError(
+                    "First file in the ensemble is not compatible with CDO!"
+                )
 
     # if there is only one file in the list, change it to a single file
     if type(x) is list:
         if len(x) == 1:
             x = x[0]
 
-    return DataSet(x)
+    d = DataSet(x)
+    d._thredds = thredds
+    return d
+
+
+def open_thredds(x=None):
+    """
+    Read thredds data as a DataSet object
+
+    Parameters
+    ---------------
+    x : str or list
+        A string or list of thredds urls, which must end with .nc.
+
+    """
+    return open_data(x = x, thredds = True)
+
+
+def open_url(x=None):
+    """
+    Read netcdf data from a url as a DataSet object
+
+    Parameters
+    ---------------
+    x : str
+        A string with a url. Prior to processing data will be downloaded to a temp folder.
+
+    """
+    return open_data(x = x)
 
 
 def merge(*datasets, match=["day", "year", "month"]):
@@ -244,7 +319,7 @@ def merge(*datasets, match=["day", "year", "month"]):
     """
     all_files = []
     for dataset in datasets:
-        if ("DataSet" in str(type(dataset))) == False:
+        if ("DataSet" in str(type(dataset))) is False:
             raise TypeError("Please check everything is a DataSet object!")
         # make sure everything has been evaluated
         dataset.run()
@@ -260,7 +335,7 @@ def merge(*datasets, match=["day", "year", "month"]):
 def cor_time(x=None, y=None):
     """
     Calculate the temporal correlation coefficient between two datasets
-    This will calculate the temporal correlation coefficient, in each grid cell, between two datasets
+    This will calculate the temporal correlation coefficient, for each time step, between two datasets. The datasets must either have the same variables or only have one variable.
 
     Parameters
     -------------
@@ -270,34 +345,34 @@ def cor_time(x=None, y=None):
         Second dataset to use
     """
 
-    if ("DataSet" in str(type(x))) == False:
+    if ("DataSet" in str(type(x))) is False:
         raise TypeError("Please check x is a dataset")
 
-    if ("DataSet" in str(type(y))) == False:
+    if ("DataSet" in str(type(y))) is False:
         raise TypeError("Please check y is a dataset")
         # make sure everything has been evaluated
 
+    x.run()
+    y.run()
+
     a = x.copy()
     b = y.copy()
 
-    a.run()
-    b.run()
-
-    ab_vars = [value for value in a.variables if value in b.variables]
-
-    if len(ab_vars) < len(a.variables):
-        a.select_variables(ab_vars)
-        print("Only using a subset of variables from x")
-        a.run()
-
-    if len(ab_vars) < len(b.variables):
-        b.select_variables(ab_vars)
-        print("Only using a subset of variables from y")
-        b.run()
-
+    if x.variables != y.variables:
+        if len(x.variables) > 1 or len(y.variables) > 1:
+            raise ValueError(
+                "This method currently only works with single variable datasets or datasets with identical variables!"
+            )
 
     target = temp_file("nc")
-    command = "cdo timcor " + a.current + " " + b.current + " " + target
+
+    if len(x.variables) == 1:
+        command = (
+            "cdo -setname,cor -timcor " + a.current + " " + b.current + " " + target
+        )
+    else:
+        command = "cdo -timcor " + a.current + " " + b.current + " " + target
+
     target = run_cdo(command, target=target)
 
     data = open_data(target)
@@ -308,7 +383,7 @@ def cor_time(x=None, y=None):
 def cor_space(x=None, y=None):
     """
     Calculate the spatial correlation coefficient between two datasets
-    This will calculate the spatial correlation coefficient, for each time step, between two datasets
+    This will calculate the spatial correlation coefficient, for each time step, between two datasets. The datasets must either have the same variables or only have one variable.
 
     Parameters
     -------------
@@ -318,33 +393,34 @@ def cor_space(x=None, y=None):
         Second dataset to use
     """
 
-    if ("DataSet" in str(type(x))) == False:
+    if ("DataSet" in str(type(x))) is False:
         raise TypeError("Please check x is a dataset")
 
-    if ("DataSet" in str(type(y))) == False:
+    if ("DataSet" in str(type(y))) is False:
         raise TypeError("Please check y is a dataset")
         # make sure everything has been evaluated
 
+    x.run()
+    y.run()
+
     a = x.copy()
     b = y.copy()
 
-    a.run()
-    b.run()
-
-    ab_vars = [value for value in a.variables if value in b.variables]
-
-    if len(ab_vars) < len(a.variables):
-        a.select_variables(ab_vars)
-        print("Only using a subset of variables from x")
-        a.run()
-
-    if len(ab_vars) < len(b.variables):
-        b.select_variables(ab_vars)
-        print("Only using a subset of variables from y")
-        b.run()
+    if x.variables != y.variables:
+        if len(x.variables) > 1 or len(y.variables) > 1:
+            raise ValueError(
+                "This method currently only works with single variable datasets or datasets with identical variables!"
+            )
 
     target = temp_file("nc")
-    command = "cdo fldcor " + a.current + " " + b.current + " " + target
+
+    if len(x.variables) == 1:
+        command = (
+            "cdo -setname,cor -fldcor " + a.current + " " + b.current + " " + target
+        )
+    else:
+        command = "cdo -fldcor " + a.current + " " + b.current + " " + target
+
     target = run_cdo(command, target=target)
 
     data = open_data(target)
@@ -373,6 +449,7 @@ class DataSet(object):
         self._merged = False
         self._safe = []
         self._zip = False
+        self._thredds = False
 
     def __getitem__(self, index):
         if type(self.current) is str:
@@ -395,25 +472,45 @@ class DataSet(object):
                 yield ff
             return
 
-    def __repr__(self):
-        # tidy up the output first
-        if isinstance(self.start, list):
-            start = str(len(self.start)) + " member ensemble"
-        if type(self.start) == str:
-            start = self.start
+    # def __repr__(self):
+    #    # tidy up the output first
+    #    if isinstance(self.start, list):
+    #        start = str(len(self.start)) + " member ensemble"
+    #    if type(self.start) == str:
+    #        start = self.start
 
+    #    if isinstance(self.current, list):
+    #        current = str(len(self.current)) + " member ensemble"
+    #    if type(self.current) == str:
+    #        current = self.current
+
+    #    return (
+    #        "<nctoolkit.DataSet>:\nstart: "
+    #        + start
+    #        + "\ncurrent: "
+    #        + current
+    #        + "\noperations: "
+    #        + str(len(self.history))
+    #    )
+
+    def __repr__(self):
         if isinstance(self.current, list):
             current = str(len(self.current)) + " member ensemble"
         if type(self.current) == str:
             current = self.current
 
+        variables = []
+        for ff in self:
+            for vv in nc_variables(ff):
+                if vv not in variables:
+                    variables.append(vv)
+
         return (
-            "<nctoolkit.DataSet>:\nstart: "
-            + start
-            + "\ncurrent: "
+            "<nctoolkit.DataSet>:\nFiles: "
             + current
-            + "\noperations: "
-            + str(len(self.history))
+            + "\n"
+            + "Variables: "
+            + str_flatten(variables)
         )
 
     @property
@@ -470,15 +567,14 @@ class DataSet(object):
 
         all_variables = []
         for ff in self:
-            all_variables+= nc_variables(ff)
+            all_variables += nc_variables(ff)
 
-        all_variables= list(set(all_variables))
+        all_variables = list(set(all_variables))
 
         all_variables.sort()
 
         return all_variables
 
-
     @property
     def months(self):
         """
@@ -487,7 +583,7 @@ class DataSet(object):
 
         all_months = []
         for ff in self:
-            all_months+= nc_months(ff)
+            all_months += nc_months(ff)
 
         all_months = list(set(all_months))
 
@@ -503,7 +599,7 @@ class DataSet(object):
 
         all_levels = []
         for ff in self:
-            all_levels+= nc_levels(ff)
+            all_levels += nc_levels(ff)
 
         all_levels = list(set(all_levels))
 
@@ -511,7 +607,6 @@ class DataSet(object):
 
         return all_levels
 
-
     @property
     def times(self):
         """
@@ -520,7 +615,7 @@ class DataSet(object):
 
         all_times = []
         for ff in self:
-            all_times+= nc_times(ff)
+            all_times += nc_times(ff)
 
         all_times = list(set(all_times))
 
@@ -536,7 +631,7 @@ class DataSet(object):
 
         all_years = []
         for ff in self:
-            all_years+= nc_years(ff)
+            all_years += nc_years(ff)
 
         all_years = list(set(all_years))
 
@@ -544,10 +639,6 @@ class DataSet(object):
 
         return all_years
 
-
-
-
-
     @property
     def variables_detailed(self):
         """
@@ -849,3 +940,13 @@ class DataSet(object):
     from nctoolkit.zonals import zonal_min
     from nctoolkit.zonals import zonal_max
     from nctoolkit.zonals import zonal_range
+
+    from nctoolkit.shift import shift_hours
+    from nctoolkit.shift import shift_days
+
+    from nctoolkit.append import append
+
+    from nctoolkit.meridonials import meridonial_mean
+    from nctoolkit.meridonials import meridonial_min
+    from nctoolkit.meridonials import meridonial_max
+    from nctoolkit.meridonials import meridonial_range
