@@ -1,8 +1,5 @@
-
-import copy
 import glob
 import os
-import pandas as pd
 
 # function to find files in directory with a specified variable
 
@@ -26,21 +23,20 @@ def create_ensemble(path="", var=None, recursive=True):
 
     # make sure the path exists
 
-    if os.path.exists(path) == False:
+    if os.path.exists(path) is False:
         raise ValueError("The path provided does not exist!")
 
     # make sure the path ends with "/" if it is not empty
     if path != "":
-        if path.endswith("/") == False:
+        if path.endswith("/") is False:
             path = path + "/"
 
     if recursive:
-        files = [f for f in glob.glob(path + "/**/*.nc", recursive=True)]
+        files = [f for f in glob.glob(path + "/**/*.nc*", recursive=True)]
     else:
-        files = [f for f in glob.glob(path + "*.nc")]
+        files = [f for f in glob.glob(path + "*.nc*")]
 
     if len(files) == 0:
         raise ValueError("There is no data in the target directory")
 
     return files
-
