@@ -1,25 +1,23 @@
-
 import copy
 import warnings
 import subprocess
 
-from nctoolkit.cleanup import cleanup, disk_clean
+from nctoolkit.cleanup import cleanup
 from nctoolkit.flatten import str_flatten
 from nctoolkit.runthis import run_this, run_nco
-from nctoolkit.session import nc_safe
 from nctoolkit.temp_file import temp_file
 
 
 def cdo_version():
     """Function to find cdo version"""
-    cdo_check = subprocess.run("cdo --version", shell = True,stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    cdo_check = subprocess.run(
+        "cdo --version", shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE
+    )
     cdo_check = str(cdo_check.stderr).replace("\\n", "")
     cdo_check = cdo_check.replace("b'", "").strip()
     return cdo_check.split("(")[0].strip().split(" ")[-1]
 
 
-
-
 def ensemble_percentile(self, p=None):
     """
     Calculate an ensemble percentile
@@ -58,27 +56,14 @@ def ensemble_percentile(self, p=None):
     self._merged = True
 
 
-def ensemble_nco(self, method, vars=None, ignore_time=False):
+def ensemble_nco(self, method, ignore_time=False):
     """
     NCO Method to calculate an ensemble stat from a list of files
     """
-    # Throw an error if there is only a single file in the tracker
-
-    if vars is not None:
-        if type(vars) == str:
-            vars = [vars]
-
-        if type(vars) is not list:
-            raise TypeError("vars supplied is not a list or str!")
-    # This method cannot possibly be chained. Release it
-
     self.run()
 
     ff_ensemble = copy.deepcopy(self.current)
 
-    if type(ff_ensemble) is not list:
-        warnings.warn(message="There is only one file in the dataset")
-
     if type(self.current) is str:
         ff_ensemble = [copy.deepcopy(self.current)]
 
@@ -86,16 +71,10 @@ def ensemble_nco(self, method, vars=None, ignore_time=False):
     target = temp_file("nc")
 
     # generate the nco call
-    if ignore_time == False:
-        if vars is None:
-            nco_command = f'ncea -y {method} {str_flatten(ff_ensemble, " ")} {target}'
-        else:
-            nco_command = f'ncea -y {method} -v {str_flatten(vars, ",")} {str_flatten(ff_ensemble, " ")} {target}'
+    if ignore_time is False:
+        nco_command = f'ncea -y {method} {str_flatten(ff_ensemble, " ")} {target}'
     else:
-        if vars is None:
-            nco_command = f'ncra -y {method} {str_flatten(ff_ensemble, " ")} {target}'
-        else:
-            nco_command = f'ncra -y {method} -v {str_flatten(vars, ",")} {str_flatten(ff_ensemble, " ")} {target}'
+        nco_command = f'ncra -y {method} {str_flatten(ff_ensemble, " ")} {target}'
 
     # run the call
     target = run_nco(nco_command, target)
@@ -112,7 +91,7 @@ def ensemble_nco(self, method, vars=None, ignore_time=False):
     self.disk_clean()
 
 
-def ensemble_max(self, nco = False, ignore_time=False):
+def ensemble_max(self, nco=False, ignore_time=False):
     """
     Calculate an ensemble maximum
 
@@ -130,11 +109,10 @@ def ensemble_max(self, nco = False, ignore_time=False):
         if type(self.current) is not list:
             warnings.warn(message="There is only one file in the dataset")
 
-
         if ignore_time is False:
             cdo_command = "cdo --sortname -ensmax"
         else:
-            if cdo_version() is not "1.9.3":
+            if cdo_version() != "1.9.3":
                 cdo_command = "cdo -timmax --sortname -ensmax"
             else:
                 cdo_command = "cdo --sortname -ensmax"
@@ -152,9 +130,7 @@ def ensemble_max(self, nco = False, ignore_time=False):
     ensemble_nco(self, "max", ignore_time=ignore_time)
 
 
-
-
-def ensemble_min(self, nco = False, ignore_time=False):
+def ensemble_min(self, nco=False, ignore_time=False):
     """
     Calculate an ensemble min
 
@@ -165,18 +141,16 @@ def ensemble_min(self, nco = False, ignore_time=False):
     ignore_time : boolean
         If True the min is calculated over all time steps. If False, the ensemble min is calculated for each time steps; for example, if the ensemble is made up of monthly files the min for each month will be calculated.
     """
+    if type(self.current) is not list:
+        warnings.warn(message="There is only one file in the dataset")
 
     if nco is False:
         self.run()
 
-        if type(self.current) is not list:
-            warnings.warn(message="There is only one file in the dataset")
-
-
         if ignore_time is False:
             cdo_command = "cdo --sortname -ensmin"
         else:
-            if cdo_version() is not "1.9.3":
+            if cdo_version() != "1.9.3":
                 cdo_command = "cdo -timmin --sortname -ensmin"
             else:
                 cdo_command = "cdo --sortname -ensmin"
@@ -184,16 +158,17 @@ def ensemble_min(self, nco = False, ignore_time=False):
         run_this(cdo_command, self)
 
         self._merged = True
-        if cdo_version() is "1.9.3":
+        if cdo_version() == "1.9.3":
             self.run()
-            self.min()
+            if ignore_time:
+                self.min()
 
         return None
 
     ensemble_nco(self, "min", ignore_time=ignore_time)
 
 
-def ensemble_mean(self, nco = False, ignore_time=False):
+def ensemble_mean(self, nco=False, ignore_time=False):
     """
     Calculate an ensemble mean
 
@@ -246,7 +221,3 @@ def ensemble_range(self):
     run_this(cdo_command, self)
 
     self._merged = True
-
-
-
-
