@@ -1,10 +1,7 @@
-
 import copy
 
-from nctoolkit.cleanup import cleanup, disk_clean
 from nctoolkit.flatten import str_flatten
 from nctoolkit.runthis import run_nco
-from nctoolkit.session import nc_safe
 from nctoolkit.temp_file import temp_file
 
 
@@ -30,7 +27,7 @@ def nco_command(self, command=None, ensemble=False):
     new_files = []
     new_commands = []
 
-    if (ensemble == False) or (len(self) == 1):
+    if (ensemble is False) or (len(self) == 1):
         for ff in self:
 
             target = temp_file(".nc")
