@@ -1,11 +1,10 @@
-
 import os
 
 from nctoolkit.api import open_data
 from nctoolkit.runthis import run_this
 
 
-def reduce_grid(self, mask):
+def reduce_grid(self, mask=None):
     """
     Reduce the dataset to non-zero locations in a mask
     Parameters
@@ -18,7 +17,7 @@ def reduce_grid(self, mask):
 
     # pull out the mask file
     if type(mask) is str:
-        if os.path.exists(mask) == False:
+        if os.path.exists(mask) is False:
             raise ValueError(f"{mask} does not exist")
         target = mask
 
@@ -36,4 +35,4 @@ def reduce_grid(self, mask):
     cdo_command = f"cdo -reducegrid,{targeted_mask.current}"
 
     run_this(cdo_command, self, output="ensemble")
-    self.release()
+    self.run()
