@@ -1,14 +1,11 @@
-
 import copy
 import os
 import pandas as pd
 import subprocess
 import warnings
-import xarray as xr
 
 from nctoolkit.api import open_data
-from nctoolkit.cleanup import cleanup, disk_clean
-from nctoolkit.flatten import str_flatten
+from nctoolkit.cleanup import cleanup
 from nctoolkit.generate_grid import generate_grid
 from nctoolkit.runthis import run_this, run_cdo
 from nctoolkit.session import nc_safe
@@ -39,7 +36,7 @@ def regrid(self, grid=None, method="bil"):
         grid_type = "df"
 
     if type(grid) is str:
-        if os.path.exists(grid) == False:
+        if os.path.exists(grid) is False:
             raise ValueError("grid file supplied does not exist")
         grid_type = "nc"
 
@@ -56,7 +53,7 @@ def regrid(self, grid=None, method="bil"):
         raise ValueError("grid supplied is not valid")
 
     # check that the remapping method is valid
-    if (method in {"bil", "bic", "nn"}) == False:
+    if (method in {"bil", "bic", "nn"}) is False:
         raise ValueError("remapping method is invalid. Please check")
 
     # check the number of grids in the dataset
@@ -67,11 +64,6 @@ def regrid(self, grid=None, method="bil"):
 
     self.run()
 
-    if type(self.current) is list:
-        orig_files = copy.deepcopy(self.current)
-    else:
-        orig_files = [copy.deepcopy(self.current)]
-
     for ff in self:
         cdo_result = subprocess.run(
             f"cdo griddes {ff}",
@@ -98,7 +90,9 @@ def regrid(self, grid=None, method="bil"):
     for key in grid_split:
         # first we need to generate the weights for remapping
         # and add this to the files created list and self.weights
-        tracker = open_data(grid_split[key], suppress_messages=True)
+        tracker = open_data(
+            grid_split[key], suppress_messages=True, thredds=self._thredds
+        )
 
         weights_nc = temp_file("nc")
 
@@ -145,5 +139,6 @@ def regrid(self, grid=None, method="bil"):
 
     self.current = new_files
 
+    self._thredds = False
     cleanup()
     self.disk_clean()
