@@ -1,15 +1,14 @@
-
 import copy
 import os
 import re
 import subprocess
-import sys
+import platform
 import warnings
 import multiprocessing
 
 from nctoolkit.cleanup import cleanup
 from nctoolkit.flatten import str_flatten
-from nctoolkit.session import nc_safe, nc_protected, session_info
+from nctoolkit.session import nc_protected, session_info
 from nctoolkit.temp_file import temp_file
 
 
@@ -41,7 +40,7 @@ def tidy_command(command):
 
     command = command.strip()
 
-    if session_info["thread_safe"] == False:
+    if session_info["thread_safe"] is False:
         command = command.replace("-L ", " ").replace("cdo ", "cdo -L ")
     else:
         command = command.replace("-L ", " ")
@@ -55,25 +54,26 @@ def run_nco(command, target, out_file=None, overwrite=False):
         command.startswith("ncea ")
         or command.startswith("ncra ")
         or command.startswith("ncatted")
-    ) == False:
+    ) is False:
         raise ValueError("This is not a valid NCO command")
 
     # Make sure it is not attempting to overwrite a protected file
     if out_file is None:
         if command.split()[-1] in nc_protected:
-            if overwrite == False:
+            if overwrite is False:
                 raise ValueError("Attempting to overwrite an opened file")
 
-    if session_info["temp_dir"] == "/tmp/":
-        result = os.statvfs("/tmp/")
-        result = result.f_frsize * result.f_bavail
+    if platform.system() == "Linux":
+        if session_info["temp_dir"] == "/tmp/":
+            result = os.statvfs("/tmp/")
+            result = result.f_frsize * result.f_bavail
 
-        if result < 1 * 1e9:
-            session_info["temp_dir"] == "/var/tmp/"
-            if target.startswith("/tmp"):
-                new_target = target.replace("/tmp/", "/var/tmp/")
-                command = command.replace(target, new_target)
-                target = target.replace("/tmp/", "/var/tmp/")
+            if result < 1 * 1e9:
+                session_info["temp_dir"] == "/var/tmp/"
+                if target.startswith("/tmp"):
+                    new_target = target.replace("/tmp/", "/var/tmp/")
+                    command = command.replace(target, new_target)
+                    target = target.replace("/tmp/", "/var/tmp/")
 
     out = subprocess.Popen(
         command,
@@ -114,11 +114,11 @@ def run_nco(command, target, out_file=None, overwrite=False):
             warnings.warn(message=f"NCO warning: {str(result)}")
 
     if target != "":
-        if os.path.exists(target) == False:
+        if os.path.exists(target) is False:
             raise ValueError(f"{command} was not successful. Check output")
     else:
         actual_target = command.split(" ")[-1].strip()
-        if os.path.exists(actual_target) == False:
+        if os.path.exists(actual_target) is False:
             raise ValueError(f"{command} was not successful. Check output")
 
     if target != "":
@@ -135,21 +135,22 @@ def run_cdo(command, target, out_file=None, overwrite=False):
 
     if out_file is None:
         if os.path.exists(command.split()[-1]):
-            if overwrite == False:
+            if overwrite is False:
                 raise ValueError("Attempting to overwrite file")
 
-    if session_info["temp_dir"] == "/tmp/":
-        result = os.statvfs("/tmp/")
-        result = result.f_frsize * result.f_bavail
+    if platform.system() == "Linux":
+        if session_info["temp_dir"] == "/tmp/":
+            result = os.statvfs("/tmp/")
+            result = result.f_frsize * result.f_bavail
 
-        if result < 1 * 1e9:
-            session_info["temp_dir"] == "/var/tmp/"
-            if target.startswith("/tmp"):
-                new_target = target.replace("/tmp/", "/var/tmp/")
-                command = command.replace(target, new_target)
-                target = target.replace("/tmp/", "/var/tmp/")
+            if result < 1 * 1e9:
+                session_info["temp_dir"] == "/var/tmp/"
+                if target.startswith("/tmp"):
+                    new_target = target.replace("/tmp/", "/var/tmp/")
+                    command = command.replace(target, new_target)
+                    target = target.replace("/tmp/", "/var/tmp/")
 
-    if command.startswith("cdo ") == False:
+    if command.startswith("cdo ") is False:
         raise ValueError("The command does not start with cdo!")
 
     out = subprocess.Popen(
@@ -314,7 +315,7 @@ def run_cdo(command, target, out_file=None, overwrite=False):
                 category=Warning,
             )
 
-    if os.path.exists(target) == False:
+    if os.path.exists(target) is False:
         raise ValueError(f"{command} was not successful. Check output")
 
     session_info["latest_size"] = os.path.getsize(target)
@@ -329,7 +330,7 @@ def run_this(os_command, self, output="one", out_file=None):
     if type(self.current) is str:
         output = "ensemble"
 
-    if self._execute == False:
+    if self._execute is False:
         if len(self._hold_history) == len(self.history):
             self.history.append(os_command)
         else:
@@ -394,7 +395,6 @@ def run_this(os_command, self, output="one", out_file=None):
 
             pool.close()
             pool.join()
-            new_current = []
             for k, v in results.items():
                 target_list.append(v.get())
 
@@ -422,16 +422,17 @@ def run_this(os_command, self, output="one", out_file=None):
                 os_command = os_command.replace("  ", " ")
 
             # ensure there is sufficient space in /tmp if it is to be used
-            all_sizes = 0
+            if platform.system() == "Linux":
+                all_sizes = 0
 
-            for ff in self:
-                all_sizes += file_size(ff)
+                for ff in self:
+                    all_sizes += file_size(ff)
 
-            result = os.statvfs("/tmp/")
-            result = result.f_frsize * result.f_bavail
+                result = os.statvfs("/tmp/")
+                result = result.f_frsize * result.f_bavail
 
-            if result < (2 * all_sizes):
-                session_info["temp_dir"] == "/var/tmp/"
+                if result < (2 * all_sizes):
+                    session_info["temp_dir"] == "/var/tmp/"
 
             target = temp_file("nc")
 
