@@ -1,4 +1,3 @@
-
 import glob
 import os
 
@@ -11,6 +10,7 @@ session_info = dict()
 nc_safe = []
 
 html_files = []
+temp_dirs = set()
 
 nc_protected = []
 
@@ -19,11 +19,11 @@ def session_files():
 
     candidates = []
 
-    mylist = [f for f in glob.glob("/tmp/*.*")]
-    mylist = mylist + [f for f in glob.glob("/var/tmp/*.*")]
-    mylist = [f for f in mylist if session_info["stamp"] in f]
-    for ff in mylist:
-        candidates.append(ff)
+    for directory in temp_dirs:
+        mylist = [f for f in glob.glob(f"{directory}/*")]
+        mylist = [f for f in mylist if session_info["stamp"] in f]
+        for ff in mylist:
+            candidates.append(ff)
 
     candidates = list(set(candidates))
     candidates = [x for x in candidates if os.path.exists(x)]
